import time


def now_timestamp() -> int:
    """Now timestamp (Second)"""

    return int(time.time())
